@@ -25,9 +25,8 @@ Check the HTTP status for a resource.
 
 =cut
 
-use 5.008;
-use vars qw($VERSION);
-$VERSION = '2.002';
+use v5.10.1;  # Mojolicious is v5.10.1 and later
+our $VERSION = '2.003';
 
 use parent 'Test::Builder::Module';
 
@@ -122,10 +121,10 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2002-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2002-2018, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the terms of the Artistic License 2.0.
 
 =cut
 
